
setFirstYear <- function(rwl, n = 0) {
  rownames(rwl) <- as.integer(rownames(rwl)) + n
  as.data.frame(rwl)
}
